@@ -35,47 +35,27 @@
 #' c.pred = predict(c.forest, X.test)
 #'
 #' @export
-custom_forest <- function(X, Y, sample.fraction = 0.5, mtry = ceiling(2*ncol(X)/3), 
+custom_forest <- function(X, Y, sample.fraction = 0.5, mtry = NULL, 
     num.trees = 2000, num.threads = NULL, min.node.size = NULL, keep.inbag = FALSE, 
     honesty = TRUE, alpha = 0.05, seed = NULL) {
-        
-    if (is.null(mtry)) {
-        mtry <- 0
-    } else if (!is.numeric(mtry) | mtry < 0) {
-        stop("Error: Invalid value for mtry")
-    }
+
+    validate_X(X)
+    if(length(Y) != nrow(X)) { stop("Y has incorrect length.") }
     
-    verbose = FALSE
-    
-    if (is.null(num.threads)) {
-        num.threads <- 0
-    } else if (!is.numeric(num.threads) | num.threads < 0) {
-        stop("Error: Invalid value for num.threads")
-    }
-    
-    if (is.null(min.node.size)) {
-        min.node.size <- 0
-    } else if (!is.numeric(min.node.size) | min.node.size < 0) {
-        stop("Error: Invalid value for min.node.size")
-    }
+    mtry <- validate_mtry(mtry, X)
+    num.threads <- validate_num_threads(num.threads)
+    min.node.size <- validate_min_node_size(min.node.size)
+    sample.fraction <- validate_sample_fraction(sample.fraction)
+    seed <- validate_seed(seed)
     
+    no.split.variables <- numeric(0)
     sample.with.replacement <- FALSE
-    
-    if (!is.logical(keep.inbag)) {
-        stop("Error: Invalid value for keep.inbag")
-    }
-    
-    if (!is.numeric(sample.fraction) | sample.fraction <= 0 | sample.fraction > 1) {
-        stop("Error: Invalid value for sample.fraction. Please give a value in (0,1].")
-    }
-    
-    if (is.null(seed)) {
-        seed <- runif(1, 0, .Machine$integer.max)
-    }
+    verbose <- FALSE
+    keep.inbag <- FALSE
     
     input.data <- as.matrix(cbind(X, Y))
     variable.names <- c(colnames(X), "outcome")
-    outcome.index <- ncol(input.data)
+    outcome.index <- ncol(X) + 1
     no.split.variables <- numeric(0)
     ci.group.size <- 1
     
