@@ -50,7 +50,7 @@ instrumental_forest <- function(X, Y, W, Z, sample.fraction = 0.5, mtry = ceilin
     if(length(W) != nrow(X)) { stop("W has incorrect length.") }
     if(length(Z) != nrow(X)) { stop("Z has incorrect length.") }
     
-    mtry <- validate_mtry(mtry)
+    mtry <- validate_mtry(mtry, X)
     num.threads <- validate_num_threads(num.threads)
     min.node.size <- validate_min_node_size(min.node.size)
     sample.fraction <- validate_sample_fraction(sample.fraction)
@@ -66,11 +66,8 @@ instrumental_forest <- function(X, Y, W, Z, sample.fraction = 0.5, mtry = ceilin
     }
     
     if (!precompute.nuisance) {
-        
         input.data <- as.matrix(cbind(X, Y, W, Z))
-        
     } else {
-        
         forest.Y <- regression_forest(X, Y, sample.fraction = sample.fraction, mtry = mtry, 
                                       num.trees = min(500, num.trees), num.threads = num.threads, min.node.size = NULL, 
                                       honesty = TRUE, seed = seed, ci.group.size = 1, alpha = alpha, lambda = lambda,
@@ -90,7 +87,6 @@ instrumental_forest <- function(X, Y, W, Z, sample.fraction = 0.5, mtry = ceilin
         Z.hat = predict(forest.Z)$predictions
         
         input.data <- as.matrix(cbind(X, Y - Y.hat, W - W.hat, Z - Z.hat))
-        
     }
     
     variable.names <- c(colnames(X), "outcome", "treatment", "instrument")
@@ -132,12 +128,7 @@ predict.instrumental_forest <- function(object, newdata = NULL,
                                         estimate.variance = FALSE,
                                         ...) {
     
-    if (is.null(num.threads)) {
-        num.threads <- 0
-    } else if (!is.numeric(num.threads) | num.threads < 0) {
-        stop("Error: Invalid value for num.threads")
-    }
-    
+    num.threads <- validate_num_threads(num.threads)    
     variable.names <- character(0)
     
     if (estimate.variance) {
